@@ -99,7 +99,7 @@ class genetic_data_handler:
         self.chromosome=chr_num
         print("Genetic handler object initialized with chromosome")
 
-    def get_binary_data(self):
+    def get_binary_data(self,num_subjects= 10):
         genetic_data_output = []
         for chr_num in ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13"]:
 
@@ -107,7 +107,7 @@ class genetic_data_handler:
                                          genetic_data_path + "bim_files/" + "ukb_snp_chr" + chr_num + "_v2.bim",
                                          genetic_data_path + "fam_files/" + "ukb22418_c" + chr_num + "_b0_v2_s488176.fam",verbose=True)
             genetic_df = genetic_df.set_index({"variant": "snp"})
-            temp_output = temp_output=genetic_df.head(100)
+            temp_output = temp_output=genetic_df.head(num_subjects)
             genetic_data_output.append(temp_output)
 
             del genetic_df
