@@ -1,11 +1,6 @@
 import pandas as pd
 static_resource_path="/ocean/projects/asc170022p/shared/Data/ukBiobank/meta_data_november_2021/"
-ethnicity_encoding_dict={"-3.0":"Prefer not to answer",
-"-1.0":"Do not know",
-"1.0":"White",
-"2.0":"Mixed",
-"3.0":"Asian or Asian British",
-"4.0":"Black or Black British",
+encoding_dict={"ethnicity":{"-3.0":"Prefer not to answer", "-1.0":"Do not know", "1.0":"White", "2.0":"Mixed", "3.0":"Asian or Asian British", "4.0":"Black or Black British",
 "5.0":"Chinese",
 "6.0":"Other ethnic group",
 "1001.0":"British",
@@ -21,7 +16,12 @@ ethnicity_encoding_dict={"-3.0":"Prefer not to answer",
 "3004.0":"Any other Asian background",
 "4001.0":"Caribbean",
 "4002.0":"African",
-"4003.0":"Any other Black background"}
+"4003.0":"Any other Black background"},
+"nationality_encoding_dict":{},
+"imaging_data_dictionary":{},
+
+              }
+
 class scalar_data_handler:
 
     """
@@ -76,7 +76,7 @@ class scalar_data_handler:
         return formatted_category_list
 
 
-    def get_field_ids_for_category(self,category_name):
+    def get_field_ids_for_category(self,category_name = None):
         """
         A utility function which lets user see the associated field ids for each category, reads from a static file
         containing all the  category names and field ids
@@ -93,7 +93,7 @@ class scalar_data_handler:
         return temp_field_ids_df[temp_field_ids_df['Category'] == category_name]
 
 
-    def get_subject_list_field_ids(self,field_id):
+    def get_subject_list_field_ids(self,field_id=None):
 
         """
         A helper function which lets user see subjects having data related to a field_id. Reads a metadata file
@@ -119,7 +119,7 @@ class scalar_data_handler:
         return tempdf['eid'].unique()
 
 
-    def get_data_scalar(self, field_id,subject_id):
+    def get_data_scalar(self, field_id = None ,subject_id = None):
         """
         A helper function which lets user fetch scalar data associated with a field id and subject
 
@@ -148,3 +148,11 @@ class scalar_data_handler:
         # in each
 
         return "subject_and_field_id_counts"
+
+    def return_decoded_results(self,key_value,encoded_result):
+
+        # Using the encoding dictionary, decode the result returned from metadata files
+        return encoding_dict[key_value][encoded_result]
+
+
+
